<table>
    <thead>
        <tr>
            <th>Key</th>
            <th>Value</th>
        </tr>
    </thead>
    <tbody>
        {% for key, value in config|dictsort %}
            <tr class="{{ loop.cycle('flDebugOdd', 'flDebugEven') }}">
                <td>{{ key }}</td>
                <td><code>{{ value|printable }}</code></td>
            </tr>
        {% endfor %}
    </tbody>
</table>